@@ -487,9 +487,10 @@ class JobsTab(object):
             try:
                 w = self.job_widgets_dict[job.job_id]
                 w.update_values(job)
+                job_widgets_ordered.append(w)
+                job_widgets_dict[job.job_id] = w
             except KeyError:
                 w = JobWidget(job)
-            finally:
                 job_widgets_ordered.append(w)
                 job_widgets_dict[job.job_id] = w
 
@@ -714,32 +715,32 @@ class StuiWidget(urwid.WidgetWrap):
 
 
 class StuiApp(object):
+
+    # (name, foreground, background, mono, foreground_high, background_high)
+    palette = [
+        ("job_state_running", "light cyan", ""),
+        ("job_state_pending", "yellow", ""),
+        ("job_state_completeing", "light magenta", ""),
+        ("active_tab_label", "yellow", ""),
+        ("focus_and_active_tab_label", "yellow,underline", ""),
+        ("focus_and_inactive_tab_label", "underline", ""),
+        ("inactive_tab_label", "", ""),
+        ("disabled_tab_label", "dark gray", ""),
+        ("magenta", "light magenta", ""),
+        ("dark_gray", "dark gray", ""),
+        ("test_A", "light cyan,bold", "", ""),
+        ("reversed", "standout", ""),
+        ("bold", "bold", ""),
+        ("underline", "underline", ""),
+        ("highlight", "black", "yellow", ""),
+        ("highlight_out_of_focus", "black", "brown", ""),
+    ]
+
     def __init__(self, args):
         super().__init__()
 
-        # TODO: Do this in the background? makes startup slow
         self.cluster = backend.Cluster(args.remote)
 
-        # (name, foreground, background, mono, foreground_high, background_high)
-        self.palette = [
-            ("job_state_running", "light cyan", ""),
-            ("job_state_pending", "yellow", ""),
-            ("job_state_completeing", "light magenta", ""),
-            ("active_tab_label", "yellow", ""),
-            ("focus_and_active_tab_label", "yellow,underline", ""),
-            ("focus_and_inactive_tab_label", "underline", ""),
-            ("inactive_tab_label", "", ""),
-            ("disabled_tab_label", "dark gray", ""),
-            ("magenta", "light magenta", ""),
-            ("dark_gray", "dark gray", ""),
-            ("test_A", "light cyan,bold", "", ""),
-            ("reversed", "standout", ""),
-            ("bold", "bold", ""),
-            ("underline", "underline", ""),
-            ("highlight", "black", "yellow", ""),
-            ("highlight_out_of_focus", "black", "brown", ""),
-        ]
-
         self.w = StuiWidget(self.cluster)
 
         # TODO: Do I want to set pop_ups to True?
